MethodChannelWmi class

An implementation of WmiPlatform that uses method channels.

Inheritance

Constructors

MethodChannelWmi()

Properties

hashCode → int
The hash code for this object.
no setterinherited
methodChannel → MethodChannel
The method channel used to interact with the native platform.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getPlatformVersion() → Future<String?>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
wmicPreInstalled() → Future<bool?>
override
wmiInit({String servename = 'ROOT\\CIMV2'}) → Future<bool?>
override
wmiRelease() → Future<void>
override
wmiValue({required String fieldname, required String tablename, String condition = '', String delimiter = ';'}) → Future<String?>
override
wmiValues({required String fieldname, required String tablename, String condition = '', String delimiter = ';'}) → Future<String?>
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited